==> gdalautotest-3.7.1.tar.gz: gdalautotest-3.7.1/gdrivers/noaa_b.py <==
#!/usr/bin/env pytest
# -*- coding: utf-8 -*-
###############################################################################
# $Id$
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test functionality of NOAA_B driver.
# Author:   Even Rouault <even dot rouault at spatialys.com>
#
###############################################################################
# Copyright (c) 2022, Even Rouault <even dot rouault at spatialys.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
###############################################################################

import gdaltest
import pytest

pytestmark = pytest.mark.require_driver("NOAA_B")

###############################################################################
#


def test_noaa_b():

    tst = gdaltest.GDALTest("NOAA_B", "noaa_b/test.b", 1, 3)
    return tst.testOpen(check_gt=(1.75, 0.5, 0.0, 49.25, 0.0, -0.5))


###############################################################################
#


def test_noaa_b_little_endian():

    tst = gdaltest.GDALTest("NOAA_B", "noaa_b/test_little_endian.b", 1, 3)
    return tst.testOpen(check_gt=(1.75, 0.5, 0.0, 49.25, 0.0, -0.5))

==> gdalautotest-3.9.0rc1.tar.gz: gdalautotest-3.9.0/gdrivers/noaa_b.py <==
#!/usr/bin/env pytest
# -*- coding: utf-8 -*-
###############################################################################
# $Id$
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test functionality of NOAA_B driver.
# Author:   Even Rouault <even dot rouault at spatialys.com>
#
###############################################################################
# Copyright (c) 2022, Even Rouault <even dot rouault at spatialys.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
###############################################################################

import gdaltest
import pytest

pytestmark = pytest.mark.require_driver("NOAA_B")

###############################################################################
#


def test_noaa_b():

    tst = gdaltest.GDALTest("NOAA_B", "noaa_b/test.b", 1, 3)
    tst.testOpen(check_gt=(1.75, 0.5, 0.0, 49.25, 0.0, -0.5))


###############################################################################
#


def test_noaa_b_little_endian():

    tst = gdaltest.GDALTest("NOAA_B", "noaa_b/test_little_endian.b", 1, 3)
    tst.testOpen(check_gt=(1.75, 0.5, 0.0, 49.25, 0.0, -0.5))
